@@ -1,4 +1,4 @@
-# Copyright 2014-2019 Rumma & Ko Ltd
+# Copyright 2014-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 """
@@ -9,7 +9,7 @@ package.
 See also :ref:`lino.admin.appypod` and :doc:`/specs/appypod`.
 """
 
-import six
+# import six
 from lino.api import ad, _
 
 
@@ -18,14 +18,15 @@ class Plugin(ad.Plugin):
 
     def get_requirements(self, site):
         yield "odfpy"
-        try:
-            import appy
-            # leave unchanged if it is already installed
-        except ImportError:
-            if six.PY3:
-                yield "-e svn+https://svn.forge.pallavi.be/appy-dev/dev1#egg=appy"
-            else:
-                yield "appy"
+        yield "appy"
+        # try:
+        #     import appy
+        #     # leave unchanged if it is already installed
+        # except ImportError:
+        #     if six.PY3:
+        #         yield "-e svn+https://svn.forge.pallavi.be/appy-dev/dev1#egg=appy"
+        #     else:
+        #         yield "appy"
 
     def get_used_libs(self, html=None):
         try:
