@@ -18,6 +18,7 @@ from lino.modlib.checkdata.choicelists import Checker
 
 from lino_xl.lib.clients.choicelists import ClientStates
 from .roles import CoachingsStaff
+from .mixins import ClientChecker
 
 from lino.modlib.notify.choicelists import MessageTypes
 MessageTypes.add_item('coachings', dd.plugins.coachings.verbose_name)
@@ -71,7 +72,6 @@ class CoachingEnding(mixins.BabelNamed, mixins.Sequenced):
                     "coachings of specified type."))
 
 
-
 class Coaching(UserAuthored, mixins.DateRange, dd.ImportedFields, ChangeNotifier):
 
     class Meta:
@@ -90,8 +90,7 @@ class Coaching(UserAuthored, mixins.DateRange, dd.ImportedFields, ChangeNotifier
     workflow_state_field = 'state'
     manager_roles_required = dd.login_required(CoachingsStaff)
 
-    client = dd.ForeignKey(
-        client_model, related_name="coachings_by_client")
+    client = dd.ForeignKey(client_model, related_name="coachings_by_client")
     type = dd.ForeignKey('coachings.CoachingType', blank=True, null=True)
     primary = models.BooleanField(_("Primary"), default=False)
 
@@ -227,12 +226,6 @@ dd.update_field(
 
 
 
-class ClientChecker(Checker):
-    model = client_model
-
-    def get_responsible_user(self, obj):
-        return obj.get_primary_coach()
-
 
 
 class ClientCoachingsChecker(ClientChecker):
