@@ -40,10 +40,10 @@ class Plugin(ad.Plugin):
     def setup_explorer_menu(self, site, user_type, m):
         m = m.add_menu(self.app_label, self.verbose_name)
         m.add_action('meetings.AllMeetings')
-        
+
     def get_dashboard_items(self, user):
         for x in super(Plugin, self).get_dashboard_items(user):
             yield x
-        if user.authenticated:
+        if user.is_authenticated:
             yield self.site.models.meetings.MyMeetings
             # yield self.site.models.meetings.MyUpcommingMeetings
