@@ -139,7 +139,6 @@ class TicketTypes(dd.Table):
 #     column_names = "ref name *"
 
 
-
 class Links(dd.Table):
     model = 'tickets.Link'
     required_roles = dd.login_required(TicketsStaff)
@@ -240,13 +239,13 @@ class LinksByTicket(Links):
                     actions.append(E.br())
                     sar.known_values.update(type=lt, parent=obj)
                     sar.known_values.pop('child', None)
-                    sar._status = None  # disable status cache
+                    sar.clear_cached_status()
                     btn = sar.ar2button(None, lt.as_parent(), icon_name=None)
                     if not lt.symmetric:
                         # actions.append('/')
                         sar.known_values.update(type=lt, child=obj)
                         sar.known_values.pop('parent', None)
-                        sar._status = None  # disable status cache
+                        sar.clear_cached_status()
                         btn2 = sar.ar2button(None, lt.as_child(), icon_name=None)
                         # actions.append(btn)
                         btn = E.span(btn, '/', btn2)
@@ -297,12 +296,17 @@ class Tickets(dd.Table):
     order_by = ["-id"]
     focus_on_quick_search = True
     column_names = 'id summary:50 user:10 #topic #faculty ' \
-                   'workflow_buttons:30 #site:10 #project:10 *' # Site commented to not disturbe care
+                   'workflow_buttons:30 #site:10 #project:10 *'  # Site commented to not disturbe care
     detail_layout = 'tickets.TicketDetail'
     insert_layout = """
     summary
     end_user
     """
+    card_layout = dd.Panel(
+        """summary user
+        workflow_buttons
+        comments.CommentsByRFC""", label=_("Cards"))
+
     # insert_layout = dd.InsertLayout("""
     # # reporter #product
     # summary
@@ -347,8 +351,8 @@ class Tickets(dd.Table):
             blank=True,
             help_text=_("Only rows having this state.")),
         priority=Priorities.field(_("Priority"),
-            blank=True,
-            help_text=_("Only rows having this priority.")),
+                                  blank=True,
+                                  help_text=_("Only rows having this priority.")),
         show_assigned=dd.YesNo.field(_("Assigned"), blank=True),
         show_deployed=dd.YesNo.field(
             _("Deployed"), blank=True,
@@ -401,7 +405,7 @@ class Tickets(dd.Table):
     def get_queryset(self, ar, **filter):
         qs = super(Tickets, self).get_queryset(ar, **filter)
         return qs.select_related(
-            'user', 'assigned_to', # 'project',
+            'user', 'assigned_to',  # 'project',
             'duplicate_of', 'end_user')
 
     @classmethod
@@ -521,6 +525,7 @@ class AllTickets(Tickets):
     label = _("All tickets")
     use_paging = True
 
+
 class DuplicatesByTicket(Tickets):
     display_mode = 'html'
     label = _("Duplicates")
@@ -530,7 +535,6 @@ class DuplicatesByTicket(Tickets):
     required_roles = set([])
 
 
-
 class RefTickets(Tickets):
     label = _("Reference Tickets")
     required_roles = dd.login_required(Triager)
@@ -538,6 +542,7 @@ class RefTickets(Tickets):
     column_names = 'id ref:20 summary:50 user:10 site:10 ' \
                    'workflow_buttons:30 *'
     order_by = ["ref"]
+
     @classmethod
     def param_defaults(self, ar, **kw):
         kw = super(RefTickets, self).param_defaults(ar, **kw)
@@ -546,6 +551,7 @@ class RefTickets(Tickets):
         )
         return kw
 
+
 class UnassignedTickets(Tickets):
     if dd.is_installed('votes'):
         column_names = "summary site user votes_by_ticket *"
@@ -566,7 +572,6 @@ class UnassignedTickets(Tickets):
         return kw
 
 
-
 class TicketsByEndUser(Tickets):
     master_key = 'end_user'
     column_names = ("overview:50 workflow_buttons * ")
@@ -607,6 +612,7 @@ class PublicTickets(Tickets):
     label = _("Public tickets")
     order_by = ["-id"]
     column_names = 'overview:50 ticket_type:10 site:10 *'
+
     # filter = Q(assigned_to=None)
 
     @classmethod
@@ -695,6 +701,7 @@ class ActiveTickets(Tickets):
         # kw.update(show_standby=dd.YesNo.no)
         return kw
 
+
 class MyTickets(My, Tickets):
     # label = _("My tickets")
     required_roles = dd.login_required(Reporter)
@@ -713,6 +720,7 @@ class MyTickets(My, Tickets):
         # kw.update(show_standby=dd.YesNo.no)
         return kw
 
+
 # class TicketsSummary(Tickets):
 #     # order_by = ["state", "priority", "-id"]
 #     order_by = ["priority", "-id"]
@@ -774,7 +782,6 @@ class MyTicketsToWork(Tickets):
         return kw
 
 
-
 class SiteDetail(dd.DetailLayout):
     bottom_left = """
     description
@@ -790,7 +797,6 @@ class SiteDetail(dd.DetailLayout):
     main = """general meetings.MeetingsBySite"""
 
 
-
 class Sites(dd.Table):
     # required_roles = set()  # also for anonymous
     required_roles = dd.login_required(Reporter)
@@ -842,7 +848,6 @@ class Sites(dd.Table):
         return qs
 
 
-
 # def get_summary_columns():
 #     for ts in TicketStates.get_list_items():
 #         if ts.active:
@@ -854,6 +859,7 @@ class SitesByGroup(Sites):
     master_key = 'group'
     column_names = "detail_link parsed_description workflow_buttons *"
 
+
 class MySites(Sites):
     label = _("My sites")
     column_names = "detail_link parsed_description workflow_buttons *"
@@ -871,20 +877,20 @@ class MySites(Sites):
     #     cls.column_names += ' '.join(get_summary_columns())
 
 
-
 # class SitesOverview(MySites):
 #     label = _("Sites Overview")
 
-    # @classmethod
-    # def param_defaults(self, ar, **kw):
-    #     kw = super(MySitesDashboard, self).param_defaults(ar, **kw)
-    #     if ar.get_user().user_type.has_required_roles([TicketsStaff]):
-    #         kw['watcher'] = None
-    #     return kw
+# @classmethod
+# def param_defaults(self, ar, **kw):
+#     kw = super(MySitesDashboard, self).param_defaults(ar, **kw)
+#     if ar.get_user().user_type.has_required_roles([TicketsStaff]):
+#         kw['watcher'] = None
+#     return kw
 
 class AllSites(Sites):
     required_roles = dd.login_required(TicketsStaff)
 
+
 # # List of sites that user X has stared?
 # class SitesByPartner(Sites):
 #     master_key = 'partner'
@@ -905,6 +911,7 @@ class TicketsBySite(Tickets):
     # label = _("Known problems")
     master_key = 'site'
     column_names = "priority overview:50 ticket_type workflow_buttons *"
+
     # order_by = ["priority", "-id"]
 
     @classmethod
